pub enum GrammarContext {
AllowRegExp,
AllowDiv,
AllowJSXIdentifier,
Type,
}Expand description
The grammar context affecting how some tokens are lexed (e.g. / as a
division operator vs. a regular-expression literal). Port of
JSLexer::GrammarContext.
Variants
AllowRegExp
A RegExp can follow, so / starts a regular-expression literal.
AllowDiv
/ can follow, so it is scanned as the division operator.
AllowJSXIdentifier
/ can follow, - is part of identifiers, and > is scanned as its
own token.
Type
A type annotation: / can follow, >> scans as two separate >
tokens, and legacy octal literals are rejected as in strict mode.